==> cloudmesh-installer-5.0.1.tar.gz: cloudmesh-installer-5.0.1/tests/test_installer.py <==
###############################################################
# pip install .; pytest -v --capture=no -v --nocapture tests/test_installer..py::Test_installer.test_001
# pytest -v --capture=no tests/test_installer.py
# pytest -v  tests/test_installer.py
###############################################################

import shutil

import os
import pytest
from cloudmesh.common.util import readfile
from cloudmesh.common.Shell import Shell
from cloudmesh.common.util import banner


@pytest.mark.incremental
class Test_installer:

    def test_create_dir(self):
        banner("test_create_dir")
        path = "tmp"
        try:
            os.mkdir(path)
        except OSError:
            print(f"Creation of the directory {path} failed")
        else:
            print(f"Successfully created the directory {path}")
        os.chdir(path)
        assert True

    def test_version(self):
        banner("test_version")

        cmd = "cloudmesh-installer version"
        result = Shell.run(cmd)
        print(result)
        print()
        assert True

    def test_info(self):
        banner("test_info")
        print("PWD:", os.getcwd())

        cmd = "cloudmesh-installer info"
        result = Shell.run(cmd)
        print(result)
        print()
        assert "We found python in" in str(result)

    def test_list(self):
        banner("list")

        cmd = "cloudmesh-installer list"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh-common" in result

    def test_non_existing(self):
        banner("test_non_existing")
        print("PWD:", os.getcwd())

        cmd = "cloudmesh-installer git clone WRONG"
        result = Shell.run(cmd)
        assert True

    def test_clone_community(self):
        banner("test_clone_community")
        print("PWD:", os.getcwd())

        cmd = "cloudmesh-installer git clone community"
        result = Shell.run(cmd)
        print(result)
        assert os.path.isdir("cloudmesh-community.github.io")

    def test_clone_cms(self):
        banner("test_clone_cms")
        print("PWD:", os.getcwd())

        cmd = "cloudmesh-installer git clone cms"
        result = Shell.run(cmd)
        print("RESULT:", result)

        assert os.path.isdir("cloudmesh-cmd5")

    def test_clone_ls(self):
        banner("test_clone_ls")
        print("PWD:", os.getcwd())
        banner("ls")

        cmd = "ls"
        result = Shell.run(cmd)
        print(result)


    def test_install_cms(self):
        banner("test_install_cms")
        print("PWD:", os.getcwd())

        cmd = "cloudmesh-installer install cms"
        result = Shell.run(cmd)
        print("RESULT:", result)
        assert os.path.isdir("cloudmesh-cmd5/cloudmesh_cmd5.egg-info")

    def test_cms_help(self):
        banner("test_cms_help")
        print("PWD:", os.getcwd())

        cmd = "cms help"
        result = Shell.run(cmd)
        print(result)
        assert "quit" in result

    def test_cms_info(self):
        banner("test_cms_info")
        print("PWD:", os.getcwd())

        cmd = "cms info"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh.common" in result

    def test_cms_verion(self):
        banner("test_cms_version")
        print("PWD:", os.getcwd())

        cmd = "cms version"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh.common" in result


class other:
    def test_delete_dir(self):
        path = "tmp"
        shutil.rmtree(path)
        assert True

==> cloudmesh-installer-5.0.2.tar.gz: cloudmesh-installer-5.0.2/tests/test_installer.py <==
###############################################################
# pip install .; pytest -v --capture=no -v --nocapture tests/test_installer..py::Test_installer.test_001
# pytest -v --capture=no tests/test_installer.py
# pytest -v  tests/test_installer.py
###############################################################

import shutil

import os
import pytest
from cloudmesh.common.Shell import Shell
from cloudmesh.common.console import Console
from cloudmesh.common.util import banner


@pytest.mark.incremental
class Test_installer:

    def test_create_dir(self):
        banner("test_create_dir")
        path = "tmp"
        if os.path.isdir('./tmp'):
            if os.path.isdir('./tmp/cloudmesh-common'):
                try:
                    shutil.rmtree('./tmp')
                except OSError:
                    Console.error("Failed to remove directory, exiting.")
                    os._exit(1)
            else:
                Console.error("cowardly exiting because i don't know "
                              "if anything valuable is in tmp")
                os.exit(1)
        try:
            os.mkdir(path)
        except OSError:
            print(f"Creation of the directory {path} failed")
        else:
            print(f"Successfully created the directory {path}")
        os.chdir(path)
        assert True

    def test_version(self):
        banner("test_version")

        cmd = "cmsi version"
        result = Shell.run(cmd)
        print(result)
        print()
        assert True

    def test_info(self):
        banner("test_info")
        print("PWD:", os.getcwd())

        cmd = "cmsi info"
        result = Shell.run(cmd)
        print(result)
        print()
        assert "We found python in" in str(result)

    def test_list(self):
        banner("list")

        cmd = "cmsi list"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh-common" in result

    def test_non_existing(self):
        banner("test_non_existing")
        print("PWD:", os.getcwd())

        cmd = "cmsi git clone WRONG"
        try:
            result = Shell.run(cmd)
            assert False
        except RuntimeError:
            assert True

    def test_clone_community(self):
        banner("test_clone_community")
        print("PWD:", os.getcwd())

        cmd = "cmsi git clone community"
        result = Shell.run(cmd)
        print(result)
        assert os.path.isdir("cloudmesh-community.github.io")

    def test_clone_cms(self):
        banner("test_clone_cms")
        print("PWD:", os.getcwd())

        cmd = "cmsi git clone cms"
        result = Shell.run(cmd)
        print("RESULT:", result)

        assert os.path.isdir("cloudmesh-cmd5")

    def test_clone_ls(self):
        banner("test_clone_ls")
        print("PWD:", os.getcwd())
        banner("ls")

        cmd = "ls"
        result = Shell.run(cmd)
        print(result)


    def test_install_cms(self):
        banner("test_install_cms")
        print("PWD:", os.getcwd())

        cmd = "cmsi install cms"
        result = Shell.run(cmd)
        print("RESULT:", result)

    # this is not possible to check.
    # when one runs pytest,
    # the python process will have to be
    # rerun for the installed module to be
    # available.
    #
    # def test_import_cms(self):
    #     banner("test_import_cms")
    #     print("PWD:", os.getcwd())

    #     # Try to import the module and check if it raises an ImportError
    #     try:
    #         import cloudmesh.shell
    #         assert True
    #     except ImportError:
    #         assert False

    def test_cms_help(self):
        banner("test_cms_help")
        print("PWD:", os.getcwd())

        cmd = "cms help"
        result = Shell.run(cmd)
        print(result)
        assert "quit" in result

    def test_cms_info(self):
        banner("test_cms_info")
        print("PWD:", os.getcwd())

        cmd = "cms info"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh.common" in result

    def test_cms_verion(self):
        banner("test_cms_version")
        print("PWD:", os.getcwd())

        cmd = "cms version"
        result = Shell.run(cmd)
        print(result)
        assert "cloudmesh.common" in result


class other:
    def test_delete_dir(self):
        path = "tmp"
        shutil.rmtree(path)
        assert True
